class Bgcolor:

    # Just a bunch of colors in one place.
    
    DEFAULT  = '\033[0m'
    WARNING  = '\033[33m'
    PURPLE   = '\033[35m'
    GREEN    = '\033[32m'
    BOLD     = '\033[1m'
    GRAY     = '\033[2m'
    BLUE     = '\033[34m'
    CYAN     = '\033[36m'
    RED      = '\033[31m'